@@ -11,7 +11,7 @@ import "hint" HLint.Builtin.All
 error = Prelude.readFile ==> bad
 
 error = (x :: Int) ==> (x :: Int32)
-    where _ = notTypeSafe
+    where _ = noTypeCheck
 
 
 error "Test1" = scanr ==> scanr
@@ -38,6 +38,7 @@ error = a * (b+c) ==> undefined
 
 error = Array.head ==> head
 error = tail ==> Array.tail
+warn = id Control.Arrow.*** id ==> id
 
 error = zip [1..length x] x ==> zipFrom 1 x
 
@@ -88,6 +89,9 @@ import Array(head); test = head -- head
 import Array as A; test = A.head -- head
 test = tail -- Array.tail
 import qualified Array as B; test = tail -- B.tail
+import Control.Arrow; test = id *** id -- id
+test = id Control.Arrow.*** id -- id
+import Control.Arrow as Q; test = id Q.*** id -- id
 zip [1..length x]
 zip [1..length x] x -- zipFrom 1 x
 
