@@ -5,11 +5,12 @@ module HLint(hlint, Suggestion, suggestionLocation, suggestionSeverity, Severity
 
 import Control.Applicative
 import Control.Monad.Extra
+import Control.Exception
 import System.Console.CmdArgs.Verbosity
 import Data.List
 import System.Exit
-import System.IO
 import System.IO.Extra
+import Data.Tuple.Extra
 import Prelude
 
 import Data.Version
@@ -30,6 +31,7 @@ import Util
 import Parallel
 import HSE.All
 
+
 -- | A suggestion - the @Show@ instance is of particular use.
 newtype Suggestion = Suggestion {fromSuggestion :: Idea}
                      deriving (Eq,Ord)
@@ -109,20 +111,21 @@ hlintMain cmd@CmdMain{..} = do
     let flags = parseFlagsSetExtensions (cmdExtensions cmd) $ defaultParseFlags{cppFlags=cmdCpp cmd, encoding=encoding}
     if null cmdFiles && not (null cmdFindHints) then do
         hints <- concatMapM (resolveFile cmd Nothing) cmdFindHints
-        mapM_ (\x -> putStrLn . fst =<< findSettings2 flags x) hints >> return []
+        mapM_ (putStrLn . fst <=< findSettings2 flags) hints >> return []
      else if null cmdFiles then
         exitWithHelp
-     else if cmdRefactor then do
+     else if cmdRefactor then
          withTempFile (\t ->  runHlintMain cmd (Just t) flags)
      else runHlintMain cmd Nothing flags
 
 runHlintMain :: Cmd -> Maybe FilePath -> ParseFlags -> IO [Suggestion]
-runHlintMain cmd@(CmdMain{..}) fp flags = do
+runHlintMain cmd@CmdMain{..} fp flags = do
   files <- concatMapM (resolveFile cmd fp) cmdFiles
   if null files
     then error "No files found"
     else runHints cmd{cmdFiles=files} flags
 
+{-# ANN readAllSettings "HLint: ignore Use let" #-}
 readAllSettings :: Cmd -> ParseFlags -> IO [Setting]
 readAllSettings cmd@CmdMain{..} flags = do
     files <- cmdHintFiles cmd
@@ -147,14 +150,14 @@ runHints cmd@CmdMain{..} flags = do
         then putStrLn . showIdeasJson $ showideas
         else if cmdSerialise then do
           hSetBuffering stdout NoBuffering
-          print $ map (\i -> (show i, ideaRefactoring i)) showideas
-        else if cmdRefactor then do
+          print $ map (show &&& ideaRefactoring) showideas
+        else if cmdRefactor then
           case cmdFiles of
             [file] -> do
               -- Ensure that we can find the executable
               path <- checkRefactor (if cmdWithRefactor == "" then Nothing else Just cmdWithRefactor)
               -- writeFile "hlint.refact"
-              let hints =  show $ map (\i -> (show i, ideaRefactoring i)) showideas
+              let hints =  show $ map (show &&& ideaRefactoring) showideas
               withTempFile $ \f -> do
                 writeFile f hints
                 runRefactoring path file f cmdRefactorOptions
@@ -180,24 +183,24 @@ runRefactoring :: FilePath -> FilePath -> FilePath -> String -> IO ExitCode
 runRefactoring rpath fin hints opts =  do
   let args = [fin, "-v0"] ++ words opts ++ ["--refact-file", hints]
   (_, _, _, phand) <- createProcess $ proc rpath args
-  hSetBuffering stdin LineBuffering
+  try $ hSetBuffering stdin LineBuffering :: IO (Either IOException ())
   hSetBuffering stdout LineBuffering
   -- Propagate the exit code from the spawn process
   waitForProcess phand
 
 checkRefactor :: Maybe FilePath -> IO FilePath
 checkRefactor rpath = do
-  let excPath = (fromMaybe "refactor" rpath)
+  let excPath = fromMaybe "refactor" rpath
   mexc <- findExecutable excPath
   case mexc of
     Just exc ->  do
-      vers <- readP_to_S parseVersion . tail <$> (readProcess exc ["--version"] "")
+      vers <- readP_to_S parseVersion . tail <$> readProcess exc ["--version"] ""
       case vers of
-        [] -> putStrLn "Unabled to determine version of refactor" >> (return exc)
+        [] -> putStrLn "Unabled to determine version of refactor" >> return exc
         (last -> (version, _)) -> if versionBranch version >= [0,1,0,0]
                                     then return exc
                                     else error "Your version of refactor is too old, please upgrade to the latest version"
-    Nothing ->  error $ unlines ["Could not find refactor"
+    Nothing ->  error $ unlines [ "Could not find refactor"
                                 , "Tried with: " ++ excPath ]
 
 evaluateList :: [a] -> IO [a]
