@@ -97,8 +97,8 @@ possImport i (UnQual _ x) = not (importQualified i) && maybe True f (importSpecs
             where ms = map g xs
 
         g :: ImportSpec S -> Maybe Bool -- does this import cover the name x
-        g (IVar _ _ y) = Just $ x =~= y
-        g (IAbs _ y) = Just $ x =~= y
+        g (IVar _ y) = Just $ x =~= y
+        g (IAbs _ _ y) = Just $ x =~= y
         g (IThingAll _ y) = if x =~= y then Just True else Nothing
         g (IThingWith _ y ys) = Just $ x `elem_` (y : map fromCName ys)
 
