@@ -3,7 +3,7 @@ module HSE.Type(module HSE.Type, module Export) where
 
 -- Almost all from the Annotated module, but the fixity resolution from Annotated
 -- uses the unannotated Assoc enumeration, so export that instead
-import Language.Haskell.Exts.Annotated as Export hiding (parse, loc, parseFile, paren, Assoc(..))
+import Language.Haskell.Exts.Annotated as Export hiding (parse, loc, paren, Assoc(..))
 import Language.Haskell.Exts as Export(Assoc(..))
 import Data.Generics.Uniplate.Data as Export
 
