@@ -17,6 +17,7 @@ module Hint.Comment(commentHint) where
 import Hint.Type
 import Data.Char
 import Data.List.Extra
+import Refact.Types(Refactoring(ModifyComment))
 
 
 pragmas = words $
@@ -32,5 +33,6 @@ commentHint c@(Comment True span s)
 commentHint _ = []
 
 suggest :: String -> Comment -> String -> Idea
-suggest msg (Comment typ pos s1) s2 = rawIdea Warning msg pos (f s1) (Just $ f s2) []
+suggest msg (Comment typ pos s1) s2 = rawIdea Warning msg pos (f s1) (Just $ f s2) [] refact
     where f s = if typ then "{-" ++ s ++ "-}" else "--" ++ s
+          refact = [ModifyComment (toRefactSrcSpan pos) (f s2)]
