@@ -48,7 +48,7 @@ listRecHint _ _ = concatMap f . universe
             let y = addCase x
             guard $ recursiveStr `notElem` varss y
             -- Maybe we can do better here maintaining source formatting?
-            return $ (idea severity ("Use " ++ use) o y [Replace Decl (toSS o) [] (prettyPrint y)])
+            return $ idea severity ("Use " ++ use) o y [Replace Decl (toSS o) [] (prettyPrint y)]
 
 
 recursiveStr = "_recursive_"
