@@ -3,14 +3,14 @@
 module Report(writeReport) where
 
 import Idea
-import Control.Arrow
+import Data.Tuple.Extra
 import Data.List
 import Data.Maybe
 import Data.Version
 import System.FilePath
 import HSE.All
 import Paths_hlint
-import Language.Haskell.HsColour.CSS
+import HsColour
 
 
 writeTemplate :: FilePath -> [(String,[String])] -> FilePath -> IO ()
@@ -38,27 +38,24 @@ writeReport dataDir file ideas = writeTemplate dataDir inner file
         getClass i = "hint" ++ f hints (hintName i) ++ " file" ++ f files (srcSpanFilename $ ideaSpan i)
             where f xs x = show $ fromJust $ findIndex ((==) x . fst) xs
 
-        list mode xs = zipWith f [0..] xs
+        list mode = zipWith f [0..]
             where
                 f i (name,n) = "<li><a id=" ++ show id ++ " href=\"javascript:show('" ++ id ++ "')\">" ++
                                escapeHTML name ++ " (" ++ show n ++ ")</a></li>"
                     where id = mode ++ show i
 
 
-code = hscolour False
-
-
 writeIdea :: String -> Idea -> [String]
 writeIdea cls Idea{..} =
     ["<div class=" ++ show cls ++ ">"
     ,escapeHTML (showSrcLoc (getPointLoc ideaSpan) ++ ": " ++ show ideaSeverity ++ ": " ++ ideaHint) ++ "<br/>"
     ,"Found<br/>"
-    ,code ideaFrom] ++
+    ,hsColourHTML ideaFrom] ++
     (case ideaTo of
         Nothing -> []
         Just to ->
             ["Why not" ++ (if to == "" then " remove it." else "") ++ "<br/>"
-            ,code to]) ++
+            ,hsColourHTML to]) ++
     [let n = showNotes ideaNote in if n /= "" then "<span class='note'>Note: " ++ n ++ "</span>" else ""
     ,"</div>"
     ,""]
