@@ -1,18 +1,21 @@
-{-# LANGUAGE PatternGuards, ViewPatterns, RecordWildCards #-}
+{-# LANGUAGE PatternGuards, ViewPatterns #-}
 
 module Settings(
     Severity(..), Classify(..), HintRule(..), Note(..), showNotes, Setting(..),
     defaultHintName, isUnifyVar,
     findSettings, readSettings,
-    readSettings2, readPragma, findSettings2
+    readSettings2, readPragma, findSettings2, addInfix
     ) where
 
-import HSE.All
-import Data.Char
-import Data.List
 import Data.Monoid
+import HSE.All
+import Control.Monad.Extra
+import Data.Char
+import Data.Either
+import Data.List.Extra
 import System.FilePath
 import Util
+import Prelude
 
 
 defaultHintName :: String
@@ -73,9 +76,9 @@ showNotes = intercalate ", " . map show . filter use
 -- | How to classify an 'Idea'. If any matching field is @\"\"@ then it matches everything.
 data Classify = Classify
     {classifySeverity :: Severity -- ^ Severity to set the 'Idea' to.
-    ,classifyHint :: String -- ^ 'ideaHint'.
-    ,classifyModule :: String -- ^ 'ideaModule'.
-    ,classifyDecl :: String -- ^ 'ideaDecl'.
+    ,classifyHint :: String -- ^ Match on 'Idea' field 'ideaHint'.
+    ,classifyModule :: String -- ^ Match on 'Idea' field 'ideaModule'.
+    ,classifyDecl :: String -- ^ Match on 'Idea' field 'ideaDecl'.
     }
     deriving Show
 
@@ -106,7 +109,7 @@ data Setting
 -- Return the list of settings commands
 readSettings2 :: FilePath -> [FilePath] -> [String] -> IO [Setting]
 readSettings2 dataDir files hints = do
-    (builtin,mods) <- fmap unzipEither $ concatMapM (readHints dataDir) $ map Right files ++ map Left hints
+    (builtin,mods) <- fmap partitionEithers $ concatMapM (readHints dataDir) $ map Right files ++ map Left hints
     return $ map Builtin builtin ++ concatMap moduleSettings_ mods
 
 moduleSettings_ :: Module SrcSpanInfo -> [Setting]
@@ -142,9 +145,9 @@ findSettings dataDir file contents = do
     res <- parseModuleEx flags file contents
     case res of
         Left (ParseError sl msg err) -> exitMessage $ "Parse failure at " ++ showSrcLoc sl ++ ": " ++ msg ++ "\n" ++ err
-        Right m -> do
+        Right (m, _) -> do
             ys <- sequence [f $ fromNamed $ importModule i | i <- moduleImports m, importPkg i `elem` [Just "hint", Just "hlint"]]
-            return $ concat2 $ ([],[m]) : ys
+            return $ concatUnzip $ ([],[m]) : ys
     where
         f x | Just x <- "HLint.Builtin." `stripPrefix` x = return ([x],[])
             | Just x <- "HLint." `stripPrefix` x = findSettings dataDir (dataDir </> x <.> "hs") Nothing
@@ -155,17 +158,17 @@ readSetting :: Scope -> Decl_ -> [Setting]
 readSetting s (FunBind _ [Match _ (Ident _ (getSeverity -> Just severity)) pats (UnGuardedRhs _ bod) bind])
     | InfixApp _ lhs op rhs <- bod, opExp op ~= "==>" =
         let (a,b) = readSide $ childrenBi bind in
-        [SettingMatchExp $ HintRule severity (headDef defaultHintName names) s (fromParen lhs) (fromParen rhs) a b]
+        [SettingMatchExp $ HintRule severity (head $ snoc names defaultHintName) s (fromParen lhs) (fromParen rhs) a b]
     | otherwise = [SettingClassify $ Classify severity n a b | n <- names2, (a,b) <- readFuncs bod]
     where
-        names = filter notNull $ getNames pats bod
+        names = filter (not . null) $ getNames pats bod
         names2 = ["" | null names] ++ names
 
 readSetting s x | "test" `isPrefixOf` map toLower (fromNamed x) = []
 readSetting s (AnnPragma _ x) | Just y <- readPragma x = [SettingClassify y]
-readSetting s (PatBind an (PVar _ name) _ bod bind) = readSetting s $ FunBind an [Match an name [] bod bind]
+readSetting s (PatBind an (PVar _ name) bod bind) = readSetting s $ FunBind an [Match an name [] bod bind]
 readSetting s (FunBind an xs) | length xs /= 1 = concatMap (readSetting s . FunBind an . return) xs
-readSetting s (SpliceDecl an (App _ (Var _ x) (Lit _ y))) = readSetting s $ FunBind an [Match an (toNamed $ fromNamed x) [PLit an y] (UnGuardedRhs an $ Lit an $ String an "" "") Nothing]
+readSetting s (SpliceDecl an (App _ (Var _ x) (Lit _ y))) = readSetting s $ FunBind an [Match an (toNamed $ fromNamed x) [PLit an (Signless an) y] (UnGuardedRhs an $ Lit an $ String an "" "") Nothing]
 readSetting s x@InfixDecl{} = map Infix $ getFixity x
 readSetting s x = errorOn x "bad hint"
 
@@ -180,8 +183,8 @@ readPragma o = case o of
         f name (Lit _ (String _ s _)) | "hlint:" `isPrefixOf` map toLower s =
                 case getSeverity a of
                     Nothing -> errorOn o "bad classify pragma"
-                    Just severity -> Just $ Classify severity (ltrim b) "" name
-            where (a,b) = break isSpace $ ltrim $ drop 6 s
+                    Just severity -> Just $ Classify severity (trimStart b) "" name
+            where (a,b) = break isSpace $ trimStart $ drop 6 s
         f name (Paren _ x) = f name x
         f name (ExpTypeSig _ x _) = f name x
         f _ _ = Nothing
@@ -189,9 +192,9 @@ readPragma o = case o of
 
 readSide :: [Decl_] -> (Maybe Exp_, [Note])
 readSide = foldl f (Nothing,[])
-    where f (Nothing,notes) (PatBind _ PWildCard{} Nothing (UnGuardedRhs _ side) Nothing) = (Just side, notes)
-          f (Nothing,notes) (PatBind _ (fromNamed -> "side") Nothing (UnGuardedRhs _ side) Nothing) = (Just side, notes)
-          f (side,[]) (PatBind _ (fromNamed -> "note") Nothing (UnGuardedRhs _ note) Nothing) = (side,g note)
+    where f (Nothing,notes) (PatBind _ PWildCard{} (UnGuardedRhs _ side) Nothing) = (Just side, notes)
+          f (Nothing,notes) (PatBind _ (fromNamed -> "side") (UnGuardedRhs _ side) Nothing) = (Just side, notes)
+          f (side,[]) (PatBind _ (fromNamed -> "note") (UnGuardedRhs _ note) Nothing) = (side,g note)
           f _ x = errorOn x "bad side condition"
 
           g (Lit _ (String _ x _)) = [Note x]
@@ -199,14 +202,13 @@ readSide = foldl f (Nothing,[])
           g x = case fromApps x of
               [con -> Just "IncreasesLaziness"] -> [IncreasesLaziness]
               [con -> Just "DecreasesLaziness"] -> [DecreasesLaziness]
-              [con -> Just "RemovesError",str -> Just a] -> [RemovesError a]
-              [con -> Just "ValidInstance",str -> Just a,var -> Just b] -> [ValidInstance a b]
+              [con -> Just "RemovesError",fromString -> Just a] -> [RemovesError a]
+              [con -> Just "ValidInstance",fromString -> Just a,var -> Just b] -> [ValidInstance a b]
               _ -> errorOn x "bad note"
 
           con :: Exp_ -> Maybe String
           con c@Con{} = Just $ prettyPrint c; con _ = Nothing
           var c@Var{} = Just $ prettyPrint c; var _ = Nothing
-          str c = if isString c then Just $ fromString c else Nothing
 
 
 -- Note: Foo may be ("","Foo") or ("Foo",""), return both
@@ -221,7 +223,7 @@ readFuncs x = errorOn x "bad classification rule"
 
 
 getNames :: [Pat_] -> Exp_ -> [String]
-getNames ps _ | ps /= [] && all isPString ps = map fromPString ps
+getNames ps _ | ps /= [], Just ps <- mapM fromPString ps = ps
 getNames [] (InfixApp _ lhs op rhs) | opExp op ~= "==>" = map ("Use "++) names
     where
         lnames = map f $ childrenS lhs
@@ -249,7 +251,7 @@ findSettings2 flags file = do
     case x of
         Left (ParseError sl msg _) ->
             return ("-- Parse error " ++ showSrcLoc sl ++ ": " ++ msg, [])
-        Right m -> do
+        Right (m, _) -> do
             let xs = concatMap (findSetting $ UnQual an) (moduleDecls m)
                 s = unlines $ ["-- hints found in " ++ file] ++ map prettyPrint xs ++ ["-- no hints found" | null xs]
                 r = concatMap (readSetting mempty) xs
@@ -258,7 +260,7 @@ findSettings2 flags file = do
 
 findSetting :: (Name S -> QName S) -> Decl_ -> [Decl_]
 findSetting qual (InstDecl _ _ _ (Just xs)) = concatMap (findSetting qual) [x | InsDecl _ x <- xs]
-findSetting qual (PatBind _ (PVar _ name) Nothing (UnGuardedRhs _ bod) Nothing) = findExp (qual name) [] bod
+findSetting qual (PatBind _ (PVar _ name) (UnGuardedRhs _ bod) Nothing) = findExp (qual name) [] bod
 findSetting qual (FunBind _ [InfixMatch _ p1 name ps rhs bind]) = findSetting qual $ FunBind an [Match an name (p1:ps) rhs bind]
 findSetting qual (FunBind _ [Match _ name ps (UnGuardedRhs _ bod) Nothing]) = findExp (qual name) [] $ Lambda an ps bod
 findSetting _ x@InfixDecl{} = [x]
@@ -273,7 +275,7 @@ findExp name vs (Lambda _ ps bod) | length ps2 == length ps = findExp name (vs++
 findExp name vs Var{} = []
 findExp name vs (InfixApp _ x dot y) | isDot dot = findExp name (vs++["_hlint"]) $ App an x $ Paren an $ App an y (toNamed "_hlint")
 
-findExp name vs bod = [PatBind an (toNamed "warn") Nothing (UnGuardedRhs an $ InfixApp an lhs (toNamed "==>") rhs) Nothing]
+findExp name vs bod = [PatBind an (toNamed "warn") (UnGuardedRhs an $ InfixApp an lhs (toNamed "==>") rhs) Nothing]
     where
         lhs = g $ transform f bod
         rhs = apps $ Var an name : map snd rep
